#!/bin/bash
set -ex

SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )
sudo sysctl -w net.ipv4.ip_local_reserved_ports=44000

export FI_EFA_USE_DEVICE_RDMA=1
export FI_PROVIDER=efa
export FI_EFA_FORK_SAFE=1

export NEURON_FUSE_SOFTMAX=1
export NEURON_RT_ASYNC_EXEC_MAX_INFLIGHT_REQUESTS=7
export MALLOC_ARENA_MAX=128
export XLA_DOWNCAST_BF16=1
export NEURON_CC_FLAGS="--cache_dir=/home/ubuntu/cache_dir_neuron/"

export XLA_IR_DEBUG=1
export XLA_HLO_DEBUG=1
export NEURON_FRAMEWORK_DEBUG=1
export NEURON_USE_EAGER_DEBUG_MODE=1
export NEURON_CC_FLAGS="--log_level=INFO"

export NEURON_RT_EXEC_TIMEOUT=1200

PROCESSES_PER_NODE=32
WORLD_SIZE=1
NODEID=0
HOSTNAME=`hostname`

DISTRIBUTED_ARGS="--nproc_per_node $PROCESSES_PER_NODE"
LOG_PATH=logs

mkdir -p $LOG_PATH
echo "Nodeinfo NODEID $NODEID hostname $HOSTNAME"
echo $DISTRIBUTED_ARGS
echo "PROCESSES_PER_NODE: $PROCESSES_PER_NODE"

# Global batch size
#GBS=1024
GBS=4
# Input sequence length
SEQ_LEN=128
# Pipeline parallel degree
PP_DEGREE=4
# Tensor parallel degree
TP_DEGREE=8
# Data paralell size
DP=$(($PROCESSES_PER_NODE * $WORLD_SIZE / $TP_DEGREE / $PP_DEGREE))
echo "Data paralell size: $DP"
# Batch size per model replica
BS=$(($GBS / $DP))
echo "Batch size per model replica: $BS"
# Number microbatches for pipeline execution
# Setting same as BS so each microbatch contains a single datasample
NUM_MICROBATCHES=$BS

#DATA_PATH="/home/ubuntu/examples_datasets/wikicorpus_llama2_7B_tokenized_4k"
DATA_PATH="/home/ubuntu/qwb_demo/data/wikitext2/train"

max_steps=2
tb_dir="~/tensorboard/simple_model_compile"


torchrun $DISTRIBUTED_ARGS run_simple_model_nxd.py \
    --train_batch_size $BS \
    --use_meta_device_init 0 \
    --training_dir $DATA_PATH \
    --training_config $SCRIPT_DIR/simple_model_config \
    --num_hidden_layers 16 \
    --max_steps $max_steps \
    --seq_len $SEQ_LEN \
    --pipeline_parallel_size $PP_DEGREE \
    --tensor_parallel_size $TP_DEGREE \
    --num_microbatches $NUM_MICROBATCHES \
    --vocab_size 128 \
    --embedding_dim 256 \
    --lr 0.00015 \
    --min_lr 1e-05 \
    --beta1 0.9 \
    --beta2 0.95 \
    --weight_decay 0.1 \
    --warmup_steps 2 \
    --constant_steps 0 \
    --use_zero1_optimizer 1 \
    --use_selective_checkpoint 1 \
    --tb_dir $tb_dir |& tee $LOG_PATH/log
